@@ -1,7 +1,7 @@
-import akiwi
+import akiwi.app as kiwi
 
 def main():
-    app = akiwi.Application()
+    app = kiwi.Application()
     return app.run_with_command()
 
 if __name__ == "__main__":
